@@ -152,7 +152,7 @@ class Render:
             f'-outputName:{str(self.scene.workdir / f"0.{extension}")}',
         ]
         if self.texture:
-            logger.debug(f"Using textures: {self.texture.dst.glob('*')}")
+            logger.debug(f"Using textures: {list(self.texture.dst.glob('*'))}")
             args.append(f'-bitmapPath:{self.texture.dst}')
         args.append(str(self.scene.localfile))
         logger.debug(f"Params = {args}")
